package com.lqkj.link.module.zone.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.lqkj.link.module.zone.domain.*;
import com.lqkj.link.module.zone.repository.TmpGeomInfoRepository;
import com.lqkj.link.module.zone.repository.TmpLayerInfoRepository;
import com.lqkj.link.module.zone.service.TmpGeomService;
import com.lqkj.link.module.zone.service.TmpLayerInfoService;
import org.apache.commons.lang3.StringUtils;
import org.checkerframework.checker.units.qual.A;
import org.locationtech.jts.geom.Coordinate;
import org.locationtech.jts.geom.GeometryFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;


@Service
public class TmpGeomServiceImpl implements TmpGeomService {

    @Autowired
    private TmpGeomInfoRepository tmpGeomInfoRepository;

    @Autowired
    private TmpLayerInfoService tmpLayerInfoService;


    @Override
    public List<TmpGeomInfo> findAll(Integer zoneId, Integer userId, Integer status) {
        return tmpGeomInfoRepository.findAllByParam(zoneId, userId, status);
    }

    @Transactional
    @Override
    public void saveTmpGeom(TmpOneZoneGeomInfos geomInfos) {
        tmpLayerInfoService.saveTmpLayer(geomInfos);
        saveGeomByZone(geomInfos);
    }

    private void saveGeomByZone(TmpOneZoneGeomInfos geomInfos) {
        GeometryFactory geometryFactory = new GeometryFactory();
        // 保存元素
        if (geomInfos.getModifyGeomList() != null && geomInfos.getModifyGeomList().size() > 0) {
            for (TmpGeomInfo geomInfo : geomInfos.getModifyGeomList()) {
                geomInfo.setTrans(geomInfo.getLocation());
                JSONObject pointObject = geomInfo.getLocation().getJSONObject("translation");
                geomInfo.setCreateTime(new Date());
                geomInfo.setGeom(geometryFactory.createPoint(new Coordinate(
                        Double.parseDouble(pointObject.get("x").toString()),
                        Double.parseDouble(pointObject.get("y").toString()),
                        Double.parseDouble(pointObject.get("z").toString()))));
                if (StringUtils.isBlank(geomInfo.getLayerId())) {
                    geomInfo.setLayerId(null);
                }
            }
            tmpGeomInfoRepository.saveAll(geomInfos.getModifyGeomList());
        }

        // 删除元素
        if (geomInfos.getDeleteGeomList() != null && geomInfos.getDeleteGeomList().size() > 0)
            tmpGeomInfoRepository.deleteAllByIdInBatch(geomInfos.getDeleteGeomList());

    }
}
